***********************************************************************************
*** This do file creates the database for 
*** Inequality and happiness: When perceived social mobility and economic reality do not match
***Christian Bjrnskov, Axel Dreher, Justina A.V. Fischer, Jan Schnellenbach, Kai Gehring
***


*****************************************************************************************
*** Last update:March 20, 2012 A
*****************************************************************************************
/* Note: This do file contains three parts: 											*/
/* 1) Preparation of data			  													*/
/* 2) Merging of data files																*/
/* 3) Regression analysis																*/
/* To replicate the results change local DIR to the directory where you store the raw data contained in the ZIP File						*/
/* Running the do file creates the transformed data in the new folder "data processed,"	*/
/* The corresponding output tables are saved in the new folder "output tables"	 		*/
/* The log file is also saved in the folder "tables"								*/
*****************************************************************************************

drop _all
clear matrix
version 12.1
set mem 2000m
set mat 2000
set virtual on 
set more off

capture net install ivreg2, from(http://fmwww.bc.edu/RePEc/bocode/i)				/* checks whether ivreg2 is installed */
capture net install xtoverid2, from(http://www-personal.umich.edu/~nicholsa/stata)	/* checks whether xtoverid is installed */
capture net install wbopendata, from(http://fmwww.bc.edu/RePEc/bocode/w)			/* checks whether wbopendata is installed */
 ssc installestout
 ssc install outreg2
 ssc install tabout

***********************************************************************************
local DIR = "................................................................."  /*change relative path to the directory where the files are located */
cd "`DIR'"
***********************************************************************************

** checks whether folder "data processed" (where transformed data are stored) and "output tables" (where tables are stored) exist and creates it if not
program define confirmdir, rclass
 	local cwd `"`c(pwd)'"'
	quietly capture cd `"`1'"'
	local confirmdir=_rc 
	quietly cd `"`cwd'"'
	return local confirmdir `"`confirmdir'"'
end 
	confirmdir `"data processed"'	  /* does folder "data processed" exist? */
		if `r(confirmdir)'!=0  {  /* folder does not yet exist */
			mkdir "data processed"  /* makes the folder  */
					      } 
	      else {
			di "folder data processed already exists"
			}
	confirmdir `"tables"'		  /* does folder "output tables" exist? */
		if `r(confirmdir)'!=0  {  /* folder does not yet exist */
			mkdir "tables"  /* makes the folder  */
					      } 
	      else {
			di "folder tables already exists"
			}
program drop confirmdir

capture log using "output tables\Bjornskov, Dreher, Fischer, Schnellenbach, Gehring.log", replace


*******************************************************************************************************************************************
************************************************ 1. Preparation of Data **********************************************************************
*******************************************************************************************************************************************


*OECD data, downloaded from http://stats.oecd.org/ on February 1, 2013
*Keys are CCode and year

use "OECD 2010 Data.dta",clear
ren code CCode
replace earning=earning*100
foreach var in earning wage_m wage_f parent persist3_f  persist3_m persist2_f  persist2_m parent_distr wage_m_corr wage_f_corr{
replace `var'=`var'/100 //Adjust to percentage values
replace `var'=1-`var'  //Adjust so that higher values mean more mobility
}
label var wage_m_corr  "Summary measure of wage persistence, male (Causa et al. 2009)"
label var wage_f_corr  "Summary measure of wage persistence, female (Causa et al. 2009)"
label var persist3_f  "Summary measure of persistence in tertiary education (Causa et al. 2009)"
label var persist3_m  "Summary measure of persistence in tertiary education (Causa et al. 2009)"
label var persist2_f  "Summary measure of persistence in below upper secondary education (Causa et al. 2009)"
label var persist2_m  "Summary measure of persistence in below upper secondary education (Causa et al. 2009)"
label var earning  "Intergenerational earnings elasticity (d'Addio 2007)"
label var parent  "Influence of parental background (Causa and Chapuis 2009)"
label var parent_distr  "Influence of parental background (Causa and Chapuis 2009)"
/*The cross-country patterns of intergenerational educational persistence change
considerably after taking country differences in the distribution of socioeconomic status into account
(Figure 6).14 More specifically, in countries like Mexico, Portugal, Luxembourg, Spain, and Turkey, where
the dispersion in students' socio-economic backgrounds is wide, even a relatively mild influence of
parental background on their achievement can lead to a large overall difference. After adjusting for the
country-specific distribution of socioeconomic status, the United States, France and Belgium are countries
where parental background has the greatest influence on students' achievement. The remainder of the
discussion of persistence in secondary education takes these distributional differences across countries into
account.
*/
*Transformation so that higher values refer to hiher mobility
saveold "data processed/OCED.dta", replace


**********************************************************************************************************************************
*Data on social mobility:  All mobility measures are recoded in a way that higher number relate to higher social mobility to ease comparisons.
**********************************************************************************************************************************
*1. Jo Blanden 2013:CROSS-COUNTRY RANKINGS IN INTERGENERATIONAL MOBILITY: A COMPARISON OF APPROACHES FROM ECONOMICS AND SOCIOLOGY - Income  elasticity
*2. Hertz et al. 2007: The inheritance of educational inequality: international comparisons and fifty-year trends - Educational Persistence across generation
*3.Chevalier et al. 2003:  A multi-country study of inter-generational educational mobility  - Educational Mobility

use "blanden.dta", clear
ren ccode CCode
drop country
saveold "data processed/Blanden.dta", replace
use "chevalier.dta",clear
ren ccode CCode
keep CCode combined_rank_chevalier
saveold "data processed/Chevalier.dta", replace 
use "hertz.dta",clear
ren ccode CCode 
drop country
merge m:m CCode using "data processed/Blanden.dta" ,nogen
merge m:m CCode using "data processed/Chevalier.dta", nogen
drop if CCode=="" |CCode=="."
label var elasticity_hertz "Intergenerational regression coefficient  education, Hertz et al.,high is more mobile"
label var correlation_hertz "Intergenerational correlation in educational attainment (Hertz et al. (2007)"
label var   income_elastiticity_blanden "Intergenerational income elasticity (Blanden 2013)"
label var combined_rank_chevalier "Mobility in educational level  (Chevalier 2004)"
label var rank_hertz_elasticity "Intergenerational regression rank, high is more mobile"
label var rank_correlation_hertz  "Intergenerational correlation in educational attainment (Hertz et al. (2007)"
***Adjust social mobility measures so that higher values are always more mobility
replace combined_rank_chevalier = (21-combined_rank_chevalier)
replace income_elastiticity_blanden=(1-income_elastiticity_blanden)
replace correlation_hertz =(1-correlation_hertz )
replace elasticity_hertz =(1-elasticity_hertz )
ren income_elastiticity_blanden inelastblan
ren combined_rank_chevalier rankchevalier 
ren rank_correlation_hertz rankcorr
ren rank_hertz_elasticity  rankelast
ren correlation_hertz corrhertz
 ren elasticity_hertz elasthertz
saveold "data processed/Mobility.dta", replace 


*Wider Income Inequality data, downloaded from http://www.wider.unu.edu/research/Database/en_GB/database/ on February 1, 2013
*Keys are CCode and year
use "wiid2c.dta", clear
drop revision
ren country3 CCode
saveold "data processed/wider.dta",replace

*Solt database, downloaded from http://myweb.uiowa.edu/fsolt/swiid/swiid.html on the 22.01.2013
*Solt, Frederick. 2009. Standardizing the World Income Inequality Database. Social Science Quarterly 90(2):231-242. SWIID Version 3.1, December 2011.
* Use of net gini better displays the real after redistribution distribution, market gini the before redistribution outcome, i.e. the need for redistribution.
clear
insheet using "SWIIDv3_1.csv", delimiter(";") case
ren Ccode CCode
egen ccode=group(CCode)
drop if ccode==.
ren year Year
destring Year,gen(year) force
drop Year
drop gini_net_se gini_market_se redist_se  redist //Unncessary
drop if year==. |CCode=="." |CCode=="0"
tsset ccode year   
tsfill, full        //Fill up missing years and fill with the closest Gini
foreach var in  country CCode  {    //fill up the missing variables
by ccode : carryforward `var' ,  replace 
}
gsort ccode-year
foreach var in  country CCode  {    //fill up the missing variables
by ccode : carryforward `var' ,  replace 
}
 ren country Country  
*Replace Inequality measures if the year of measurement is not further away than two years from the year we want. This is feasible as the survey is not done in exactly one year,
* but within a certain time period
foreach var in gini_market gini_net  {
by ccode :replace `var'=`var'[_n-1] if (`var'==. &year==2000)|  (`var'==. &year ==2005 ) |  (`var'==. &year ==1990 ) |  (`var'==. &year ==1995 )
by ccode :replace `var'=`var'[_n-2] if (`var'==. &year==2000)|  (`var'==. &year ==2005 ) |  (`var'==. &year ==1990 ) |  (`var'==. &year ==1995 )
by ccode :replace `var'=`var'[_n+1] if (`var'==. &year==2000)|  (`var'==. &year ==2005 ) |  (`var'==. &year ==1990 ) |  (`var'==. &year ==1995 )
by ccode :replace `var'=`var'[_n+2] if (`var'==. &year==2000)|  (`var'==. &year ==2005 ) |  (`var'==. &year ==1990 ) |  (`var'==. &year ==1995 )
}
saveold "data processed/Solt.dta", replace


*Country codes to merge data
clear
insheet using "codes.csv", delimiter(";") case
keep name uncode aclpcode wdicode
ren name country
ren uncode ccode
ren wdicode CCode
save "data processed/codes.dta",replace

*World Value Surveys data, downloaded from http://www.wvsevsdb.com/wvs/WVSData.jsp on the 25.01.2013
*Keys are CCode and year
use "wvs1981_2008_v20090914.dta", clear
append using "EVS.dta"
*European Value Surveys data, downloaded from...
*Used to complete the WVS which have some missings due to legal reasons
order  s003 s002  ,first
ren s003 ccode
replace ccode= 891 if ccode==911 //correct for Serbia
replace ccode= 291 if ccode==276
merge  m:m ccode using    "data processed/codes.dta" , keep(3)  nogen     //Add WID country codes and names
ren country Country
order Country aclpcode CCode, before(ccode)
*Generate year for mergin the control variables
gen year= 1995 if s002==3
replace year= 1990 if s002==2
replace year= 2000 if s002==4
replace year= 2005 if s002==5
order year,before(s002)
keep if s002 == 3 | s002 == 4 | s002==5 | s002==2 //Keep 4 waves
keep Country aclpcode CCode s002 e* f025 f024   s017   x047r s019 a168    s007   s003 s016  a009 a170 x001 x003 x003r x007 x013 - x022  x025 x025r ///
x047* x028 x011 f028 f050 a165 e051 e048  e069_03 e069_05 e069_06 e069_07 e069_08 e069_09 e069_11 e069_12 e069_17 year 
tab s002
ren e048 Optimism1
label var Optimism1 "i am good at getting what i want"
ren e051 Optimism2
label var Optimism2  "i usually count on being successful in everything i do"
rename s007 respid
rename s016 interviewlang
rename x001 sex
rename a009 health
rename a170 life_sat
rename s003 country
rename x003 age
rename x003r age_cat
rename x007 marit_stat
rename x025 education
*8 categories
rename x025r edu_Kat
*3 categories
rename x013 people_hh
rename x047 inc_scale
rename x028 occup
rename f028 service
gen trust =  a165 
replace trust = 0 if trust == 2
gen fair =  a168 -1 
replace fair = . if a165 == .
rename s019 weight
* x047cs gives country-specific scale values ( not interesting)
*education: Iran and Turkey have more than 10% missings, for whole sample 1000 obs 
*inc_scale : only Morocco, Norway and Portugal have more than 5% missing, about 15000 obs  
*too many missings for 
* g16 language at home, g017 born in this country, x051 ethnic group
*x049 size of town, people in HH  variables (x013 - x022), g004, g005: citizenship /x051: ethnic group
*TV consumption: not enough data (e188),  s016 / g016 language
* state of health: a009, e196: extent of political corruption
drop if life_sat == .
*explanatory variables
replace inc_scale = 11 if inc_scale == .
tab inc_scale, ge(inc_cat)
gen male = (sex == 1)
gen married = (marit_stat == 1)
gen cohab = (marit_stat == 2)
gen single = (marit_stat == 6)
*refgroup: divorced, widowed, separated
gen single_m = (single == 1 & male == 1)
gen single_f = (single == 1 & male == 0)
replace education = 9 if education == .
tab education, ge(edu_cat)
tab age_cat, ge(age_Kat)
ge prev_child = (x011 >=1 & x011 !=.)
ge prev_child1 = (x011 ==1)
ge prev_child2 = (x011 ==2 )
ge prev_child3 = (x011 >=3 & x011 !=.)
gen parttime = (occup == 2)
gen self_empl = (occup == 3)
gen retired =  (occup == 4)
gen housewife = (occup == 5)
gen student = (occup == 6)
gen unempl_indi = (occup == 7)
gen other = (occup == 8)
tab service,   ge(rel_att)
* never and missing form reference category 
gen belief_sup = (f050== 1)
* no political opinion
*denomination  f024 f025
gen no_rel = (f024 == 0 | f025 == 996 | f024 == . | f025 == .)
gen buddhist = (f025 == 12 | f025 == 32 | f025 == 38)
gen muslim = (f025 == 49 | f025 == 75 | f025 == 2 |f025 == 70 | f025 == 71  )
gen catholic = (f025 == 15 | f025 == 64 | f025 == 23 | f025 == 27 | f025 == 29)
gen protestant = (f025 == 9 | f025 == 10 |f025 == 5 | f025 == 19 | f025 == 20 | f025 == 25 | f025 == 36 | f025 == 44 | f025 ==46 | f025 == 60 | f025 == 61 | f025 == 68 | f025 == 62)
gen orthodox = (f025 == 52) 
gen other_christ =(f025 == 6 | f025 == 30| f025 == 18| f025 == 17 | f025 == 1 |f025 == 7 | f025 == 16 |f025 == 26 | f025 == 28 | f025 == 34 | f025 == 35 | f025 == 37 | f025 == 39 | f025 == 40 | f025 == 41 | f025 == 43 | f025 == 45 | f025 == 48  | f025 == 51 | f025 == 66 | f025 == 79 | f025 == 82 | f025 == 81 | f025 == 83)
gen rel_other = (f025 == 14 | f025 == 4 | f025 == 8 | f025 == 11 | f025 == 22 | f025 == 24 | f025 == 50 | f025 == 53 | f025 == 54 | f025 == 58 | f025 == 59 | f025 == 69 | f025 == 72 | f025 == 73 | f025 == 74 | f025 == 77 | f025 == 80 | f025 == 84 | f025 == 86)
gen jewish = (f025 == 42)
gen hindu = (f025 == 31)
gen  wvs_num = country
label var other_christ "other Christian denomination"
label var no_rel "no denomination"
label var trust "trusts most people"
label var inc_cat2 "Income level 2"
label var inc_cat3 "Income level 3"
label var inc_cat4 "Income level 4"
label var inc_cat5 "Income level 5"
label var inc_cat6 "Income level 6"
label var inc_cat7 "Income level 7"
label var inc_cat8 "Income level 8"
label var inc_cat9 "Income level 9"
label var inc_cat10 "Income level 10 (highest)"
label var inc_cat11 "no income information"
label var age_Kat2 "Age 25 - 34"
label var age_Kat3 "Age 35 - 44"
label var age_Kat4 "Age 45 - 54"
label var age_Kat5 "Age 55 - 64"
label var age_Kat6 "Age  > 64"
label var edu_cat2 "completed primary education   "
label var edu_cat3 " incomplete sec., techn.  "
label var edu_cat4 " complete sec., techn. "
label var edu_cat5 " incomplete sec., uni prep "
label var edu_cat6 " complete sec., uni prep  "
label var edu_cat7 " lower-level tertiary edu  "
label var edu_cat8 " upper-level tertiary edu "
label var edu_cat9 " education missing "
label var single_f "single female"
label var single_m "single male"
label var cohab "cohabiting"
label var prev_child1 "has had 1 child"
label var prev_child2 "has had 2 children
label var prev_child3 "has had 3 or more children"
label var unempl_indi "unemployed"
label var self_empl "selfemployed"
label var rel_att1 "service part: > once a week  "
label var rel_att2 "service part: once a week  "
label var rel_att3 "service part: one a month  "
label var rel_att4 "service part: on common holy days"
label var rel_att5 "service part: on specific holy days"
label var rel_att6 "service part: once a year"
label var rel_att7 "service part: less than once a year"
label var belief_sup "believes in superior being"
gen income_low = (x047r == 1)
gen income_middle = (x047r == 2)
gen income_high = (x047r == 3)
drop if  country==364   // "Iran" unreliable data
drop if country ==156  // "China"unreliable data
drop if country == 704 //"Vietnam" unreliable data
******Generates the variables about the perceptions of fairness**************
gen conservative2 = (e033 > = 7 & e033 !=.) 
gen left2 = (e033 < = 4 & e033 !=.) 
gen center = (e033 == 5|e033 == 6)
gen cons_mis = (e033 == .)
label var cons_mis "ideology missing"
label var conservative2 "Conservative ideology"
replace left2 = . if cons_mis == .
replace conservative2 = . if cons_mis == .
gen  more_unequal1 = (e035 > = 7 & e035 ! = .)
label var more_unequal1 "Larger incomes differences needed"
gen  more_unequal2 = (e035 < = 4)
label var more_unequal2 "Incomes should be more equal"
replace more_unequal1 = . if  e035 == .
replace more_unequal2 = . if  e035 == .
gen more_equal = more_unequal2
label var more_equal "Incomes should be more equal"
gen more_equalO=(11-e035)
label var more_equal "Incomes should be more equal ordinal"
gen hardwork1 = (e040 <=4)
label var hardwork1 "Hard work brings success in the long run"
gen hardwork2 = (e040 >=7 & e040 ! = . )
label var hardwork2 "hard work does not bring success"
replace hardwork1 = . if e040 == .
replace hardwork2 = . if e040 == .
gen laziness3 =  (e131 == 1)
replace laziness3 = .  if e131 == .
replace laziness3 = .  if e131 == 3 
replace laziness3 = 1  if e190 == 2
replace laziness3 = 0  if e190 == 3
replace laziness3 = 1  if e191 == 2
replace laziness3 = 0  if e191 == 3
tab laziness3
label var laziness3 "People are poor due to laziness, not injustice"
gen chance =  (e132 == 1 )
replace chance = .  if e132 == . 
label var chance "People have chance to escape poverty" 
gen elimination = (e146 == 1 | e146 == 2)
replace elimination = . if e146 == . 
replace elimination = 1 if (e146a == 1 |e146a == 2)
replace elimination = 0 if (e146a == 3 |e146a == 4)
label var elimination "importance to eliminate inc inequality Dummy" 
gen eliminationO= (6-e146)
label var eliminationO "It is important to eliminate income inequality	" 
gen basic = (e147 == 1 | e147 == 2)
replace basic = . if e147 == . 
replace basic = 1 if (e147a == 1 |e147a == 2)
replace basic = 0 if (e147a == 3 |e147a == 4)
label var basic "importance to guaranteeing basic needs Dummy" 
gen basicO=0
replace basicO =1 if e147==5 |e147a==5
replace basicO=2 if e147==4 |e147a==4
replace basicO=3 if e147==3 
replace basicO =4 if e147==2 |e147a==2
replace basicO =5 if e147==1 |e147a==1
label var basicO "It is important to guarantee basic needs	" 
gen eqedu = (e149 == 1 | e149 == 2 )
replace eqedu = . if e149 == . 
replace eqedu = 1 if (e149a == 1 |e149a == 2)
replace eqedu = 0 if (e149a == 3 |e149a == 4)

label var eqedu "importance of equalizing chances for edu" 
gen age_s =  age^2/100
gen age_3 = age^3/10000

*Dummies for different waves
forvalues i=2 (1) 5 {
gen Fwave`i'=(s002==`i')
}
egen ccode=group(CCode)
*Dummies for Countries
forvalues i=1 (1) 92 {
gen Fcountry`i'=(ccode==`i')
}
*Dummies for Country-Wave Fixed Effects
egen countrywave=group(CCode s002)
forvalues i=1 (1) 212 {
gen Fcowave`i'=(countrywave==`i')
}

*******************************************************************************************************************************************
************************************************ 2. Merging files ****************************************************************************
*******************************************************************************************************************************************

merge m:1 CCode year using "data processed/Solt.dta", keep(1 3) nogen

merge m:1 CCode  using "data processed/OCED.dta", keep(1 3) nogen

merge m:1 CCode  using "data processed/Mobility.dta", keep(1 3) nogen

drop if CCode=="ZAR" |CCode=="SLE" |CCode=="SEN" |CCode=="PRY" |CCode=="PAN" |CCode=="NIC" |CCode=="NER"  |CCode=="NAM"  |CCode=="MWI"  |CCode=="MOZ"   |CCode=="MDG"  |CCode=="LBR"  ///
|CCode=="KEN" |CCode=="JAM" |CCode=="HND"  |CCode=="ECU"   |CCode=="CRI"   |CCode=="CMR"   //only one observation
*Adjust Gini before redistribution to percentage values
ren gini_market gini  
replace gini = gini/100
replace gini_net=gini_net/100
label var gini "Gross Gini Coefficient (Solt database)"
tab CCode
tab year
saveold "data processed\Bjornskov, Dreher, Fischer,Schnellenbach, Gehring.dta", replace


*****************************************************************************************************************************************************************************************************************************************************
************************************************ 3. Regressions ***************************************************************************************************************************************************************************************
*****************************************************************************************************************************************************************************************************************************************************

use "data processed\Bjornskov, Dreher, Fischer,Schnellenbach, Gehring.dta", clear

*In general a table with only a number is the one intended for the main paper. A table with an a or b is a version using triple interactions or other tests for significant differences
*A table number 4.2 is the test with only the controls in xvar2, with 4.3 a table with the controls in xvar3, with 4.4 a table with controls in xvar4. xvar3 and xvar4 contain optimism questions as well and are restricted to the year 1990.
capture log using "data processed\Bjornskov, Dreher, Fischer,Schnellenbach, Gehring.dta_02.smcl", replace

**************************************************************************************************************************************************************************************
*Simple correlation, part 4.1 of the paper
*Correlation of Life satisfaction with: fairness perceptions , social mobility proxies(Indices), actual social mobility (OECD:parent, earning, wage_m , wage_f ,persist3_f  (socio-economic , others..., Income Inequality
*********Correlations
estpost corr life_sat  hardwork1 laziness3 chance  conservative2   /*civ_lib*/  earning wage_m_corr wage_f_corr inelastblan persist3_f  persist3_m persist2_f persist2_m    corrhertz  ///
 rankchevalier  gini 
est store c1
esttab c1 using "tables\Corr1.rtf", unstack not  compress replace //Number of observations is the maximum number
sort country 
preserve
*Generate aggregate measures
foreach var in life_sat  hardwork1 laziness3 chance  conservative2  earning wage_m_corr wage_f_corr persist3_f  persist3_m persist2_f persist2_m ///
elasthertz corrhertz inelastblan rankchevalier { 
egen `var'_aggr=mean(`var'), by(country)
}
bysort CCode year:gen Count=[_n]
keep if Count==1
*Correlations with Aggregate LS
corr life_sat_aggr  hardwork1_aggr laziness3_aggr chance_aggr  conservative2_aggr gini  
est store c3
estpost corr life_sat_aggr earning_aggr wage_m_corr_aggr  wage_f_corr_aggr  inelastblan persist3_f_aggr persist3_m_aggr persist2_f_aggr persist2_m_aggr  corrhertz  rankchevalier  
est store c4
esttab  c3  c4 using "tables\Corr2.rtf",  unstack not compress replace
restore,preserve

************************************************************************************************************************************************************
***Hypothesis 1: high p and SWB / 
*Tables for the appendix: Table Appendix
************************************************************************************************************************************************************

    global xvar1    age age_s age_3 male  buddhist muslim catholic protestant orthodox other_christ no_rel jewish hindu    age_Kat2 - age_Kat6  ///
   inc_cat2 - inc_cat11  edu_cat2 - edu_cat9 single_f single_m married cohab prev_child1 prev_child2 prev_child3 self_empl housewife retired ///
   other student unempl_indi rel_att1 - rel_att7 belief_sup 
   * Include all categories for descriptives
   *xvar2: Without educational outcomes, income variables, and  occupational status
global xvar2    age age_s age_3 male  buddhist muslim catholic protestant orthodox other_christ ///
no_rel jewish hindu    age_Kat2 - age_Kat6    single_f single_m married cohab prev_child1 prev_child2 prev_child3  rel_att1 - rel_att7 belief_sup 
*3 and 4 also contain a control for optimism
global xvar3    age age_s age_3 male  buddhist muslim catholic protestant orthodox other_christ no_rel jewish hindu    age_Kat2 - age_Kat6  ///
   inc_cat2 - inc_cat11  edu_cat2 - edu_cat9 single_f single_m married cohab prev_child1 prev_child2 prev_child3 self_empl housewife retired ///
   other student unempl_indi rel_att1 - rel_att7 belief_sup Optimism1 
global xvar4    age age_s age_3 male  buddhist muslim catholic protestant orthodox other_christ no_rel jewish hindu    age_Kat2 - age_Kat6  ///
   inc_cat2 - inc_cat11  edu_cat2 - edu_cat9 single_f single_m married cohab prev_child1 prev_child2 prev_child3 self_empl housewife retired ///
   other student unempl_indi rel_att1 - rel_att7 belief_sup Optimism2

*** ****************************************** ****************************************** ****************************************************************************************************************************      
   *****************************************************************Summary statistics********************************************************************************************************************************   
   *** ****************************************** ****************************************** ****************************************** *******************************************************************************  
   
   sum $xvar1  life_sat more_equalO eliminationO basicO  hardwork1   laziness3 chance conservative2 gini earning wage_m_corr wage_f_corr persist3_f persist3_m persist2_f persist2_m corrhertz ///
   inelastblan rankchevalier parent Optimism1 Optimism2
   des    $xvar1  life_sat more_equalO eliminationO basicO  hardwork1   laziness3 chance conservative2 gini earning wage_m_corr wage_f_corr persist3_f persist3_m persist2_f persist2_m corrhertz ///
   inelastblan rankchevalier parent Optimism1 Optimism2
*For Gini
reg life_sat    Fcowave* Fwave* Fcountry*   $xvar2 gini,vce(cluster countrywave)
outreg2    using "tables\APPendixCowave.xls", replace  bracket excel dec(3)     // With dynamic country wave fixed effects
outreg2   using "tables\APPendixCowaveControl2.xls",replace  bracket excel dec(3)   
***For all kinds of variables of interest
local var  hardwork1 laziness3 chance  conservative2      
tokenize "`var'"
while "`1'" ! = "`'" {  
reg life_sat   Fcountry*   Fwave*   $xvar2  `1' ,vce(cluster countrywave) 
*outreg   using "tables\table3.xls", append  excel bracket dec(3) nocons   addstat(e(r2_a)  
outreg2   using "tables\APPendix.xls", append  excel bracket dec(3)
reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  `1' , vce(cluster countrywave)
outreg2   using "tables\APPendixCowaveControl1.xls", append  excel 
reg life_sat    Fcowave* Fwave* Fcountry*   $xvar2  `1' , vce(cluster countrywave)
outreg2   using "tables\APPendixCowaveControl2.xls", append  excel 
*xi: reg life_sat i.`1'*gini   i.country  $xvar2 wave3 
*outreg   using "tables\table3.xls", append  excel bracket dec(3) nocons   addstat(e(r2_a)  
mac shift
}
*************************************************************************************** ***************************************************************************************************************************      
************************************************************Table 2 and 3 ******************************************************************************************************************************************
************************************************************************************** ****************************************************************************************************************************    

*Test equality of coefficients for the four variables: Fairness perceptions and conservativeness
*Table 2 & 3:
reg life_sat    Fcowave* Fwave* Fcountry*   $xvar2  hardwork1 , vce(cluster countrywave)
outreg2   hardwork1 using "tables\table2.xls", replace   excel bracket dec(3) nocons addnote(Income & education & occupational status  controls not included,Baseline micro controls included , Country-wave fixed effects included)
tabout Country if e(sample) using "tables\tableCountries.xls",replace format(c)  style(csv)   layout(col)  clab("table 2.1")
reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  hardwork1, vce(cluster countrywave)
tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)  clab("table 3.1")
outreg2  hardwork1 using "tables\table3.xls",  replace   excel bracket dec(3) nocons addnote(Income & education & occupational status  controls  included,Baseline micro controls included , Country-wave fixed effects included)
reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  Optimism1 hardwork1, vce(cluster countrywave)   //Check if results differ if we control for optimism
outreg2  hardwork1 Optimism1 using "tables\table3.3.xls",  replace   excel bracket dec(3) nocons addnote(Income & education & occupational status  controls  included,Baseline micro controls included , Country-wave fixed effects included)
reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  Optimism2 hardwork1, vce(cluster countrywave)   //Check if results differ if we control for optimism- Other proxy
outreg2  hardwork1 Optimism2 using "tables\table3.4.xls",  replace   excel bracket dec(3) nocons addnote(Income & education & occupational status  controls  included,Baseline micro controls included , Country-wave fixed effects included)
  reg life_sat    Fcowave* Fwave* Fcountry*   $xvar2  hardwork1 
estimates store model1
reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  hardwork1
estimates store model2
suest model1 model2,vce(cluster countrywave)
test [model1_mean]hardwork1 = [model2_mean]hardwork1
scalar hardwork1= r(chi2)
foreach var in   laziness3 chance conservative2{  
noisily reg life_sat    Fcowave* Fwave* Fcountry*   $xvar2  `var' , vce(cluster countrywave)
noisily outreg2  `var' using "tables\table2.xls", append  excel bracket dec(3) nocons  addtext(No,Yes,Yes)
tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)  clab("table 2")
noisily reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  `var' , vce(cluster countrywave)
tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)  clab("table 3")
noisily outreg2  `var' using "tables\table3.xls", append  excel bracket dec(3) nocons  addtext(Yes,Yes,Yes)
capture noisily reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  `var' Optimism1, vce(cluster countrywave)   //Check if results differ if is controlled for optimism
capture outreg2  `var'  Optimism1 using "tables\table3.3.xls", append  excel bracket dec(3) nocons
capture noisily reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  `var' Optimism2, vce(cluster countrywave)   //Check if results differ if is controlled for optimism
capture outreg2  `var' Optimism2 using "tables\table3.4.xls", append  excel bracket dec(3) nocons
noisily reg life_sat    Fcowave* Fwave* Fcountry*   $xvar2  `var' 
noisily estimates store model1
noisily reg life_sat    Fcowave* Fwave* Fcountry*   $xvar1  `var' 
noisily estimates store model2
noisily suest model1 model2,vce(cluster countrywave)
noisily test [model1_mean]`var' = [model2_mean]`var'
noisily scalar `var'= r(chi2)
}
capture log close
log using "tables\Difference of Coefficients Chi2 value.smcl ",replace
scalar list _all    //Lists the Chi-square values for significant differences across models for all four variables
log close
capture log using "data processed\Bjornskov, Dreher, Fischer,Schnellenbach, Gehring.dta_02.smcl", append

*** ****************************************** ****************************************** ***************************************************************************************************************************      
************************************************************Table 4 ************************************************************************************************************************************************
*** ****************************************** ****************************************** ***************************************************************************************************************************      

*Generate variable that measures Income and education
 	foreach var in  hardwork1   laziness3 chance conservative2   {
 foreach Mob in more_equalO eliminationO basicO  {
 capture noisily	reg `Mob'   `var'   Fcowave* Fwave* Fcountry*  `xvar1',vce(cluster countrywave)
  capture noisily tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)  
capture noisily		est store `Mob'`var'
 *capture noisily	oprobit `Mob'   `var'   Fcowave* Fwave* Fcountry*  `xvar1',vce(cluster countrywave)
*capture noisily		est store `Mob'`var'P
 }
 }
 	  capture noisily estout  more_equalOhardwork1     ///
										using    "tables\table4.txt",replace ///
				title(" `Mob'`var'")  noabbrev wrap	nolabel				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) varlabels(hardwork1  "Hard work brings success in the long run")	 ///
				mlabels("Incomes should be more equal"" " "importance to eliminate income inequality" " ""Importance of guaranteeing basic needs" " ") ///
				keep(hardwork1  )
		capture noisily estout  more_equalOlaziness3  eliminationOlaziness3  basicOlaziness3      ///
										using    "tables\table4.txt",append  keep(laziness3)  noabbrev wrap varlabels( laziness3 "People are poor due to laziness, not injustice"    ) ///
											cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) mlabels("""""")	
		capture noisily estout  more_equalOchance      ///
										using    "tables\table4.txt",append  keep(chance )	 noabbrev wrap	mlabels("""""")  ///
											cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) 	varlabels( chance "People have chance to escape poverty"    )							
		capture noisily estout  more_equalOconservative2    eliminationOconservative2   basicOconservative2    ///
										using    "tables\table4.txt",append  keep(conservative2  )	 noabbrev wrap mlabels("""""") ///
											cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) varlabels( conservative2  "Conservative ideology"    )	 
	
	*Alternatively the output for ordered probit			
  	  capture noisily estout  more_equalOhardwork1P     ///
										using    "tables\table4AP.txt",replace ///
				title(" `Mob'`var'")  noabbrev wrap	nolabel				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats( N, labels("Number of observations") fmt(0)) 	 ///
				mlabels("Incomes should be more equal" "Important to eliminate income inequality" "Importance of guaranteeing basic needs" ) ///
				keep(hardwork1  )  varlabels(hardwork1  "Hard work brings success in the long run")
					capture noisily estout  more_equalOlaziness3P eliminationOlaziness3P  basicOlaziness3P      ///
										using    "tables\table4AP.txt",append   noabbrev wrap keep(laziness3) mlabels("""""")  ///
											cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(N, labels( "Number of observations") fmt(0)) 	varlabels( laziness3 "People are poor due to laziness, not injustice"    )
		capture noisily estout  more_equalOchanceP      ///
										using    "tables\table4AP.txt",append  noabbrev wrap keep(chance )	mlabels("""""") 	///
											cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats( N,labels( "Number of observations") fmt(0)) 			varlabels( chance "People have chance to escape poverty"    )			
		capture noisily estout  more_equalOconservative2P    eliminationOconservative2P   basicOconservative2P    ///
										using    "tables\table4AP.txt",append  noabbrev wrap keep(conservative2  )	mlabels("""""") ///) 
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) 	

				
*** ****************************************** ****************************************** ***************************************************************************************************************************      
************************************************************Table 5 ************************************************************************************************************************************************
*** ****************************************** ****************************************** ***************************************************************************************************************************   
******* Hypothesis 2 second part -Table 5 - Lower LS if higher demand for redistribution - Include edu, income, occup status. 
*It is not possible to run this whole specification with Optimism, as the demand for redistribution was not measured in 1990.
*Only the demand for more equal incomes was also measured in 1990. The results are still significant at the 1% level.

 reg life_sat more_equal     gini    Fcowave* Fwave* Fcountry*    $xvar1,   vce(cluster countrywave)
  tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)  
outreg2   more_equal  using "tables\table5.xls", replace excel bracket dec(3) nocons      addstat(e(r2_a) , e(N)) ctitle(" ")  title(Subjective well-being and the demand for redistribution) ///
addnote("Notes: OLS estimation. Dependent variable is life satisfaction measured on a 10-point scale. All models include the baseline micro-variables, country-wave fixed effects and  of education, income, and occupational status. *, **, *** denote significances at the 10, 5 and 1 percent level, respectively.")

reg life_sat  elimination   gini   Fcowave* Fwave* Fcountry*   $xvar1  ,vce(cluster countrywave)
 tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)  
outreg2 elimination   using "tables\table5.xls", append excel bracket dec(3) nocons      addstat(e(r2_a) , e(N)) ctitle(" ")  
 reg life_sat more_equal     gini    Fcowave* Fwave* Fcountry*    $xvar3,   vce(cluster countrywave)
 reg life_sat more_equal     gini    Fcowave* Fwave* Fcountry*    $xvar4,   vce(cluster countrywave)

reg life_sat  basic    gini    Fcowave* Fwave* Fcountry*    $xvar1  ,vce(cluster countrywave)
 tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)  
outreg2 basic using "tables\table5.xls", append 


*** ****************************************** ****************************************** ***************************************************************************************************************************      
************************************************************Table 6 ************************************************************************************************************************************************
*** ****************************************** ****************************************** ***************************************************************************************************************************   
*****Hypothesis 3: interaktion Gini*p
***Here we interact the fairness perception values with Inequality and actual social mobility. 
*Test if values differ if the interaction differ for measures of actual social mobility from different sources
*1.4. Summary measure of persistence in wages across generations

	foreach Mob in    earning wage_m_corr  wage_f_corr inelastblan {   
egen Med`Mob'=median(`Mob')
foreach var in hardwork1 laziness3 conservative2 {
capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar1  c.`var'##c.gini if  `Mob'!=.  ,vce(cluster countrywave) 
  capture noisily  tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)  
  capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar1  c.`var'##c.gini  if `Mob' <=Med`Mob'  ,vce(cluster countrywave) 
 capture noisily  est store `var'`Mob'l
 capture noisily  reg life_sat     Fcowave* Fwave* Fcountry*   $xvar1  c.`var'##c.gini if `Mob' >Med`Mob' & `Mob'!=.       ,vce(cluster countrywave) 
   capture noisily  est store `var'`Mob'h
  	}    
  capture noisily estout conservative2`Mob'l conservative2`Mob'h hardwork1`Mob'l hardwork1`Mob'h laziness3`Mob'l laziness3`Mob'h ///
										using    "tables\table6.txt",append ///
				title(Measure of Social Mobility: `Mob')  noabbrev wrap	label				///
				cells( (b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) ) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) 	mlabels(none)   ///
				keep( c.hardwork1#c.gini   hardwork1 c.laziness3#c.gini  laziness3 c.conservative2#c.gini conservative2 ) ///
				varlabels ( hardwork1 "Hard work brings success in the long run" c.hardwork1#c.gini "Hard work x Income Inequality"   /// 
				laziness3 "People are poor due to laziness, not injustice" c.laziness3#c.gini "Laziness x Income Inequality"  c.conservative2#c.gini "Conservative ideology x Income Inequality" /// 
				conservative2 "Conservative ideology")
					drop Med`Mob'
  }
  
*** ****************************************** ****************************************** ***************************************************************************************************************************      
************************************************************Table 7 ************************************************************************************************************************************************
*** ****************************************** ****************************************** ***************************************************************************************************************************   
*1.4. Summary measure of persistence in tertiary education 

  foreach Mob in      persist2_m   persist3_m   rankcorr rankchevalier{   
egen Med`Mob'=median(`Mob')
foreach var in hardwork1 laziness3 conservative2 {
  capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar1  c.`var'##c.gini if  `Mob'!=. ,vce(cluster countrywave) 
  capture noisily tabout Country if e(sample) using "tables\tableCountries.xls",append  format(c)  style(csv)   layout(col)    //List the countries included in the regression
  capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar1  c.`var'##c.gini  if `Mob' <=Med`Mob'  ,vce(cluster countrywave) 
 capture noisily  est store `var'`Mob'l
 capture noisily  reg life_sat     Fcowave* Fwave* Fcountry*   $xvar1  c.`var'##c.gini if `Mob' >Med`Mob' & `Mob'!=.       ,vce(cluster countrywave) 
   capture noisily  est store `var'`Mob'h
  	}    
  capture noisily estout conservative2`Mob'l conservative2`Mob'h hardwork1`Mob'l hardwork1`Mob'h laziness3`Mob'l laziness3`Mob'h ///
										using    "tables\table7.txt",append ///
				title(`Mob')  noabbrev wrap	label				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) 	mlabels(none)  ///
				keep( c.hardwork1#c.gini   hardwork1 c.laziness3#c.gini  laziness3 c.conservative2#c.gini conservative2 ) ///
				varlabels ( hardwork1 "Hard work brings success in the long run" c.hardwork1#c.gini "Hard work x Income Inequality"   /// 
				laziness3 "People are poor due to laziness, not injustice" c.laziness3#c.gini "Laziness x Income Inequality"  c.conservative2#c.gini "Conservative ideology x Income Inequality" /// 
				conservative2 "Conservative ideology")
					drop Med`Mob'
  }
 
  

  
    *******************************************************************************************************************************************************************
****************************Table6a: Triple Interactions
  *******************************************************************************************************************************************************************  
 
   reg life_sat   gini   Fcowave* Fwave* Fcountry*    $xvar1    
foreach var in   earning wage_m_corr  wage_f_corr inelastblan  {   
foreach  Mob in hardwork1 laziness3     conservative2  {
 capture noisily reg life_sat c.`Mob'##c.gini##c.`var'
 capture noisily  est store `Mob'`var'1
}  
capture noisily estout 	 hardwork1`var'1  laziness3`var'1    conservative2`var'1   using    "tables\table6a.txt",append ///
				title(" `Mob'`var'")  noabbrev wrap	nolabel				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) mlabels(none)  /// 
				keep(c.hardwork1#c.gini c.hardwork1#c.gini#c.`var' c.laziness3#c.gini  c.laziness3#c.gini#c.`var' c.conservative2#c.gini  c.conservative2#c.gini#c.`var' )  ///
				varlabels ( c.hardwork1#c.gini "Hard work x Income Inequality" c.hardwork1#c.gini#c.`var' "Hard work x Income Inequality x  Mobility"  /// 
				c.laziness3#c.gini "Laziness x Income Inequality"  c.laziness3#c.gini#c.`var' "Laziness x Income Inequality x Mobility" ///
				c.conservative2#c.gini "Conservative ideology x Income Inequality" c.conservative2#c.gini#c.`var' "Conservative ideology x Income Inequality x Mobility") 
}
  
  
      *******************************************************************************************************************************************************************
****************************Table7a: Triple Interactions
  *******************************************************************************************************************************************************************  
  reg life_sat   gini   Fcowave* Fwave* Fcountry*    $xvar1    
foreach var  in    persist2_m   persist3_m   corrhertz rankchevalier  {   
foreach  Mob in hardwork1 laziness3     conservative2  {
 capture noisily reg life_sat c.`Mob'##c.gini##c.`var' Fcowave* Fwave* Fcountry*    $xvar1    , vce(cluster countrywave)
 capture noisily  est store `Mob'`var'1
}  
capture noisily estout 	 hardwork1`var'1  laziness3`var'1    conservative2`var'1   using    "tables\table7a.txt",append ///
				title(" `Mob'`var'")  noabbrev wrap	nolabel				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) mlabels(none)  /// 
		keep(c.hardwork1#c.gini c.hardwork1#c.gini#c.`var' c.laziness3#c.gini  c.laziness3#c.gini#c.`var' c.conservative2#c.gini  c.conservative2#c.gini#c.`var' )  ///
				varlabels ( c.hardwork1#c.gini "Hard work x Income Inequality" c.hardwork1#c.gini#c.`var' "Hard work x Income Inequality x  Mobility"  /// 
				c.laziness3#c.gini "Laziness x Income Inequality"  c.laziness3#c.gini#c.`var' "Laziness x Income Inequality x Mobility" ///
				c.conservative2#c.gini "Conservative ideology x Income Inequality" c.conservative2#c.gini#c.`var' "Conservative ideology x Income Inequality x Mobility") 
}
 

  ********************************************************************************************************************************************************************************************************
****************************Table6.3, contains first control for Optimism************************************************************************************************************************************
********************************************************************************************************************************************************************************************************
*****Hypothesis 3: interaktion Gini*p

	foreach Mob in  earning wage_m_corr  wage_f_corr inelastblan  {      
egen Med`Mob'=median(`Mob')
foreach var in hardwork1 laziness3 conservative2 {
  capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar3  c.`var'##c.gini  if `Mob' <=Med`Mob'  ,vce(cluster countrywave) 
 capture noisily  est store `var'`Mob'l
 capture noisily  reg life_sat     Fcowave* Fwave* Fcountry*   $xvar3  c.`var'##c.gini if `Mob' >Med`Mob' & `Mob'!=.       ,vce(cluster countrywave) 
   capture noisily  est store `var'`Mob'h   
  	}    
  capture noisily estout conservative2`Mob'l conservative2`Mob'h hardwork1`Mob'l hardwork1`Mob'h laziness3`Mob'l laziness3`Mob'h ///
										using    "tables\table6.3.txt",append ///
				title(" `Mob'`var'OECD")  noabbrev wrap	nolabel				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) mlabels(none)  ///
				keep( c.hardwork1#c.gini   hardwork1 c.laziness3#c.gini  laziness3 c.conservative2#c.gini conservative2 )   ///
				varlabels ( hardwork1 "Hard work brings success in the long run" c.hardwork1#c.gini "Hard work x Income Inequality"   /// 
				laziness3 "People are poor due to laziness, not injustice" c.laziness3#c.gini "Laziness x Income Inequality"  c.conservative2#c.gini "Conservative ideology x Income Inequality" /// 
				conservative2 "Conservative ideology")
					drop Med`Mob'
  }
  ********************************************************************************************************************************************************************************************************
****************************Table6.4, contains secondcontrol for Optimism*********************************************************************************************************************************
********************************************************************************************************************************************************************************************************
*****Hypothesis 3: interaktion Gini*p
	foreach Mob in  earning wage_m_corr  wage_f_corr inelastblan  {      
egen Med`Mob'=median(`Mob')
foreach var in hardwork1 laziness3 conservative2 {
  capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar4  c.`var'##c.gini  if `Mob' <=Med`Mob'  ,vce(cluster countrywave) 
 capture noisily  est store `var'`Mob'l
 capture noisily  reg life_sat     Fcowave* Fwave* Fcountry*   $xvar4  c.`var'##c.gini if `Mob' >Med`Mob' & `Mob'!=.       ,vce(cluster countrywave) 
   capture noisily  est store `var'`Mob'h   
  	}    
  capture noisily estout conservative2`Mob'l conservative2`Mob'h hardwork1`Mob'l hardwork1`Mob'h laziness3`Mob'l laziness3`Mob'h ///
										using    "tables\table6.4.txt",append ///
				title(" `Mob'`var'OECD")  noabbrev wrap	nolabel				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) mlabels(none)  ///
				keep( c.hardwork1#c.gini   hardwork1 c.laziness3#c.gini  laziness3 c.conservative2#c.gini conservative2 ) ///
				varlabels ( hardwork1 "Hard work brings success in the long run" c.hardwork1#c.gini "Hard work x Income Inequality"   /// 
				laziness3 "People are poor due to laziness, not injustice" c.laziness3#c.gini "Laziness x Income Inequality"  c.conservative2#c.gini "Conservative ideology x Income Inequality" /// 
				conservative2 "Conservative ideology")
					drop Med`Mob'
  }
    
	  ********************************************************************************************************************************************************************************************************
****************************Table7.3, contains first control for Optimism************************************************************************************************************************************
********************************************************************************************************************************************************************************************************

  *******************************************************************************************************************************************************************
****************************Table7.3
*******************************************************************************************************************************************************************
*****Hypothesis 3: interaktion Gini*p
	foreach Mob in   persist2_m   persist3_m   rankcorr rankchevalier   {      
egen Med`Mob'=median(`Mob')
foreach var in hardwork1 laziness3 conservative2 {
  capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar3  c.`var'##c.gini  if `Mob' <=Med`Mob'  ,vce(cluster countrywave) 
 capture noisily  est store `var'`Mob'l
 capture noisily  reg life_sat     Fcowave* Fwave* Fcountry*   $xvar3  c.`var'##c.gini if `Mob' >Med`Mob' & `Mob'!=.       ,vce(cluster countrywave) 
   capture noisily  est store `var'`Mob'h    
  	}    
  capture noisily estout conservative2`Mob'l conservative2`Mob'h hardwork1`Mob'l hardwork1`Mob'h laziness3`Mob'l laziness3`Mob'h ///
										using    "tables\table7.3.txt",append ///
				title(" `Mob'`var'OECD")  noabbrev wrap	nolabel				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) mlabels(none)  ///
				keep( c.hardwork1#c.gini   hardwork1 c.laziness3#c.gini  laziness3 c.conservative2#c.gini conservative2 ) ///
				varlabels ( hardwork1 "Hard work brings success in the long run" c.hardwork1#c.gini "Hard work x Income Inequality"   /// 
				laziness3 "People are poor due to laziness, not injustice" c.laziness3#c.gini "Laziness x Income Inequality"  c.conservative2#c.gini "Conservative ideology x Income Inequality" /// 
				conservative2 "Conservative ideology")
					drop Med`Mob'
  }
  ********************************************************************************************************************************************************************************************************
****************************Table7.4, contains secondcontrol for Optimism*********************************************************************************************************************************
********************************************************************************************************************************************************************************************************
*****Hypothesis 3: interaktion Gini*p
	foreach Mob in   persist2_m   persist3_m   rankcorr rankchevalier   {      
egen Med`Mob'=median(`Mob')
foreach var in hardwork1 laziness3 conservative2 {
  capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar4  c.`var'##c.gini  if `Mob' <=Med`Mob'  ,vce(cluster countrywave) 
 capture noisily  est store `var'`Mob'l
 capture noisily  reg life_sat     Fcowave* Fwave* Fcountry*   $xvar4  c.`var'##c.gini if `Mob' >Med`Mob' & `Mob'!=.       ,vce(cluster countrywave) 
   capture noisily  est store `var'`Mob'h
   *  capture noisily    reg life_sat     Fcowave* Fwave* Fcountry*   $xvar1  c.`var'##c.gini  if `Mob' <=Med`Mob'  
*capture noisily  estimates store model1 `var'`Mob'h
 *capture noisily  reg life_sat     Fcowave* Fwave* Fcountry*   $xvar1  c.`var'##c.gini if `Mob' >Med`Mob' & `Mob'!=.     
   *capture noisily  estimates store   `var'`Mob'l
  	}    
  capture noisily estout conservative2`Mob'l conservative2`Mob'h hardwork1`Mob'l hardwork1`Mob'h laziness3`Mob'l laziness3`Mob'h ///
										using    "tables\table7.4.txt",append ///
				title(" `Mob'`var'OECD")  noabbrev wrap	nolabel				///
				cells((b(star fmt(%-9.2f) vacant("-") label(Coef.)) se(fmt(%-9.2f) par([ ]) vacant("-") label(Std. err.))) )  style(tab)  starlevels(* 0.10 ** 0.05 *** 0.01) ///
				stats(r2_a N, labels("Adj. R-Squared" "Number of observations") fmt(2 0)) mlabels(none)  ///
				keep( c.hardwork1#c.gini   hardwork1 c.laziness3#c.gini  laziness3 c.conservative2#c.gini conservative2 ) ///
				varlabels ( hardwork1 "Hard work brings success in the long run" c.hardwork1#c.gini "Hard work x Income Inequality"   /// 
				laziness3 "People are poor due to laziness, not injustice" c.laziness3#c.gini "Laziness x Income Inequality"  c.conservative2#c.gini "Conservative ideology x Income Inequality" /// 
				conservative2 "Conservative ideology")
					drop Med`Mob'
  }
     
  
